module.exports = ({ config, paths }) => {
  const genAssetPath = (dir) => {
    return process.env.APP_MODE === 'production'
      ? `${paths.assetsSubPath}${dir}[name].[contenthash:8].[ext]`
      : '[name].[ext]'
  }

  const genUrlLoaderOptions = (dir) => {
    return {
      limit: 1024 * 8,
      name: genAssetPath(dir)
    }
  }

  config.module
    .rule('img')
    .test(/\.(png|jpe?g|gif|webp)(\?.*)?$/)
    .use('imgLoader')
    .loader('url-loader')
    .options(genUrlLoaderOptions(paths.assetsImgPath))

  config.module
    .rule('svg')
    .test(/\.(svg)(\?.*)?$/)
    .use('svgLoader')
    .loader('file-loader')
    .options({
      name: genAssetPath(paths.assetsImgPath)
    })

  config.module
    .rule('font')
    .test(/\.(woff2?|eot|ttf|otf)(\?.*)?$/i)
    .use('fontLoader')
    .loader('url-loader')
    .options(genUrlLoaderOptions(paths.assetsFontPath))

  config.module
    .rule('media')
    .test(/\.(mp4|webm|ogg|mp3|wav|flac|aac)(\?.*)?$/)
    .use('mediaLoader')
    .loader('url-loader')
    .options(genUrlLoaderOptions(paths.assetsMediaDir))
}
